@@ -1,20 +1,3 @@
-########
-# Copyright (c) 2014 GigaSpaces Technologies Ltd. All rights reserved
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#        http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
-############
-
-
 import sys
 import os
 import difflib
@@ -273,6 +256,51 @@ def parse_and_validate_label_to_delete(ctx, param, value):
         return {label_key: label_value}
 
 
+def parse_and_validate_filter_rules(ctx, param, value):
+    if value is None or ctx.resilient_parsing:
+        return
+
+    if not value:
+        raise CloudifyValidationError(
+            'ERROR: The `{0}` argument is empty'.format(param.name))
+
+    if any(pattern in value for pattern in
+           ['and', '!=', '=', 'is null', 'is not null']):
+        filter_rules_list = parse_filter_rules_list(value)
+        return {'_filter_rules': filter_rules_list}
+
+    else:
+        validate_param_value('The filter ID', value)
+        return {'_filter_id': value}
+
+
+def parse_and_validate_filter_rules_list(ctx, param, value):
+    if value is None or ctx.resilient_parsing:
+        return
+
+    if not value:
+        raise CloudifyValidationError(
+            'ERROR: The `{0}` argument is empty'.format(param.name))
+
+    return parse_filter_rules_list(value)
+
+
+def parse_filter_rules_list(raw_filter_rules):
+    filter_rules = []
+    for filter_rule in raw_filter_rules.split('and'):
+        if all(pattern not in filter_rule for pattern in
+               ['=', 'is null', 'is not null']):
+            raise CloudifyValidationError(
+                'ERROR: Filter rules must be one of: <key>=<value>, '
+                '<key>=[<value1>,<value2>,...], <key>!=<value>, '
+                '<key>!=[<value1>,<value2>,...], <key> is null, '
+                '<key> is not null')
+        filter_rules.append(filter_rule.strip().lower())
+        # The rest of the validation is done in the rest-service
+
+    return filter_rules
+
+
 def validate_name(ctx, param, value):
     if value is None or ctx.resilient_parsing:
         return
@@ -1350,7 +1378,8 @@ class Options(object):
             type=click.IntRange(1, 65535),
             help=helptexts.PORT,
         )
-        # Args for configuring self.ldap
+
+        # Args for configuring ldap
         self.ldap_server = click.option(
             '-s',
             '--ldap-server',
@@ -1397,6 +1426,61 @@ class Options(object):
             required=False,
             help=helptexts.LDAP_CA_PATH,
         )
+        self.ldap_base_dn = click.option(
+            '--ldap-base-dn',
+            required=False,
+            help=helptexts.LDAP_BASE_DN,
+        )
+        self.ldap_group_dn = click.option(
+            '--ldap-group-dn',
+            required=False,
+            help=helptexts.LDAP_GROUP_DN,
+        )
+        self.ldap_bind_format = click.option(
+            '--ldap-bind-format',
+            required=False,
+            help=helptexts.LDAP_BIND_FORMAT,
+        )
+        self.ldap_user_filter = click.option(
+            '--ldap-user-filter',
+            required=False,
+            help=helptexts.LDAP_USER_FILTER,
+        )
+        self.ldap_group_member_filter = click.option(
+            '--ldap-group-member-filter',
+            required=False,
+            help=helptexts.LDAP_GROUP_MEMBER_FILTER,
+        )
+        self.ldap_attribute_email = click.option(
+            '--ldap-attribute-email',
+            required=False,
+            help=helptexts.LDAP_ATTRIBUTE_EMAIL,
+        )
+        self.ldap_attribute_first_name = click.option(
+            '--ldap-attribute-first-name',
+            required=False,
+            help=helptexts.LDAP_ATTRIBUTE_FIRST_NAME,
+        )
+        self.ldap_attribute_last_name = click.option(
+            '--ldap-attribute-last-name',
+            required=False,
+            help=helptexts.LDAP_ATTRIBUTE_LAST_NAME,
+        )
+        self.ldap_attribute_uid = click.option(
+            '--ldap-attribute-uid',
+            required=False,
+            help=helptexts.LDAP_ATTRIBUTE_UID,
+        )
+        self.ldap_attribute_group_membership = click.option(
+            '--ldap-attribute-group-membership',
+            required=False,
+            help=helptexts.LDAP_ATTRIBUTE_GROUP_MEMBERSHIP,
+        )
+        self.ldap_nested_levels = click.option(
+            '--ldap-nested-levels',
+            required=False,
+            help=helptexts.LDAP_NESTED_LEVELS,
+        )
 
         self.node_id = click.option(
             '--node-id',
@@ -1411,6 +1495,13 @@ class Options(object):
             required=False,
             help=helptexts.RUNTIME_ONLY_EVALUATION)
 
+        self.auto_correct_types = click.option(
+            '--auto-correct-types',
+            is_flag=True,
+            default=False,
+            required=False,
+            help=helptexts.AUTO_CORRECT_TYPES)
+
         self.manager = click.option(
             '--manager',
             required=False,
@@ -1426,6 +1517,14 @@ class Options(object):
             default=False,
             help=helptexts.PLUGINS_UPDATE_ALL)
 
+        self.except_blueprints = click.option(
+            '--except-blueprint',
+            'except_blueprints',
+            multiple=True,
+            required=False,
+            help=helptexts.PLUGINS_UPDATE_EXCEPT_BLUEPRINT,
+            callback=self.parse_comma_separated)
+
         self.plugin_names = click.option(
             '--plugin-name',
             'plugin_names',
@@ -1467,6 +1566,98 @@ class Options(object):
             help=helptexts.LABELS
         )
 
+        self.async_upload = click.option(
+            '-a',
+            '--async-upload',
+            is_flag=True,
+            default=False,
+            help=helptexts.ASYNC_UPLOAD,
+        )
+
+        self.update_filter_rules = click.option(
+            '--filter-rules',
+            callback=parse_and_validate_filter_rules_list,
+            help=helptexts.FILTER_RULES
+        )
+
+        self.filter_rules = click.option(
+            '--filter',
+            callback=parse_and_validate_filter_rules,
+            help=helptexts.FILTER_RULES_OR_ID
+        )
+
+        self.frequency = click.option(
+            '--freq',
+            cls=MutuallyExclusiveOption,
+            mutually_exclusive=['rrule'],
+            required=False,
+            help=helptexts.SCHEDULE_FREQUENCY
+        )
+
+        self.count = click.option(
+            '-c',
+            '--count',
+            cls=MutuallyExclusiveOption,
+            mutually_exclusive=['rrule'],
+            required=False,
+            type=int,
+            help=helptexts.SCHEDULE_COUNT
+        )
+
+        self.weekdays = click.option(
+            '--weekdays',
+            cls=MutuallyExclusiveOption,
+            mutually_exclusive=['rrule'],
+            required=False,
+            help=helptexts.SCHEDULE_WEEKDAYS
+        )
+
+        self.rrule = click.option(
+            '--rrule',
+            cls=MutuallyExclusiveOption,
+            mutually_exclusive=['frequency', 'count', 'weekdays'],
+            required=False,
+            help=helptexts.SCHEDULE_RRULE
+        )
+
+        self.slip = click.option(
+            '--slip',
+            required=False,
+            default=0,
+            type=int,
+            help=helptexts.SCHEDULE_SLIP
+        )
+
+        self.stop_on_fail = click.option(
+            '--stop-on-fail',
+            required=False,
+            is_flag=True,
+            default=False,
+            help=helptexts.SCHEDULE_STOP_ON_FAIL
+        )
+
+        self.group_default_blueprint = click.option(
+            '--default-blueprint', '-b',
+            help=helptexts.DEP_GROUP_BLUEPRINT
+        )
+
+        self.group_description = click.option(
+            '--description',
+            help=helptexts.DEP_GROUP_DESCRIPTION
+        )
+
+        self.group_deployment_id = click.option(
+            '--deployment-id', '-d',
+            help=helptexts.DEP_GROUP_DEP_ID,
+            multiple=True
+        )
+
+        self.group_count = click.option(
+            '--count',
+            help=helptexts.DEP_GROUP_COUNT,
+            type=int
+        )
+
     def common_options(self, f):
         """A shorthand for applying commonly used arguments.
 
@@ -1626,11 +1817,12 @@ class Options(object):
             help=helptexts.BLUEPRINT_FILENAME + extra_message)
 
     @staticmethod
-    def workflow_id(default=None):
+    def workflow_id(default=None, required=False):
         return click.option(
             '-w',
             '--workflow-id',
             default=default,
+            required=required,
             help=helptexts.WORKFLOW_TO_EXECUTE.format(default))
 
     @staticmethod
@@ -1919,5 +2111,15 @@ class Options(object):
             default=default
         )
 
+    @staticmethod
+    def reevaluate_active_statuses(
+            help=helptexts.REEVALUATE_ACTIVE_STATUSES):
+        return click.option(
+            '--reevaluate-active-statuses',
+            is_flag=True,
+            default=False,
+            required=False,
+            help=help)
+
 
 options = Options()
