@@ -1,19 +1,3 @@
-########
-# Copyright (c) 2014 GigaSpaces Technologies Ltd. All rights reserved
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#        http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
-############
-
 VERBOSE = \
     "Show verbose output. You can supply this up to three times (i.e. -vvv)"
 QUIET = "Show only critical logs"
@@ -119,12 +103,11 @@ DONT_UPDATE_PLUGINS = (
 )
 
 FORCE_UPDATE = (
-    "Force running update in case a previous update on this deployment has "
-    "failed to finish successfully [This option is deprecated]"
+    "Force running the update also in case a deployment is used as a component"
 )
 FORCE_PLUGINS_UPDATE = (
-    "Force running the update in case a previous update on this blueprint has "
-    "failed to finish successfully [This option is deprecated]"
+    "Force running the update also in case a blueprint (for which the update "
+    "is executed) is used as a component"
 )
 
 DEPLOYMENT_ID = "The unique identifier for the deployment"
@@ -195,6 +178,12 @@ SET_MANAGEMENT_CREDS = (
     '(e.g. `cfy profiles use -s my_user -k ~/my/key/path`)'
 )
 
+ASYNC_UPLOAD = (
+    "Don't wait for the upload workflow to finish. Upload state can be "
+    "checked at any time using the `cfy blueprints get` or `cfy "
+    "blueprints list` commands."
+)
+
 MANAGEMENT_IP = 'The IP of the manager host machine'
 SSH_USER = 'The SSH user on the manager host machine'
 SSH_KEY = 'The path to the ssh key-file to use when connecting'
@@ -276,17 +265,54 @@ LDAP_SERVER = (
     'Should be prefixed with the protocol and include the port, '
     'e.g. ldap://192.0.2.1:389 or ldaps://192.0.2.45:636'
 )
-LDAP_USERNAME = 'The LDAP admin username to be set on the Cloudify manager'
-LDAP_PASSWORD = 'The LDAP admin password to be set on the Cloudify manager'
+LDAP_USERNAME = 'LDAP username to bind with. If not set, binds will '\
+                'be performed using the credentials of the user attempting '\
+                'to log in. If this is set, the --ldap-password option must '\
+                'also be set.'
+LDAP_PASSWORD = 'LDAP password to bind with. See ldap username for details.'
 LDAP_DOMAIN = 'The LDAP domain to be used by the server'
 LDAP_IS_ACTIVE_DIRECTORY = 'Specify whether the LDAP used for authentication' \
                            ' is Active-Directory.'
-LDAP_DN_EXTRA = 'Extra LDAP DN options.'
+LDAP_DN_EXTRA = 'Extra LDAP DN options. '\
+                '(deprecated, use --ldap-base-dn instead)'
 LDAP_CA_PATH = (
     'Path to the CA certificate LDAP communications will be encrypted with. '
     'Required if using ldaps. '
     'Must not be provided if not using ldaps.'
 )
+LDAP_BASE_DN = (
+    'The base DN for searches, etc. If not provided, this will be derived '
+    'from the domain used, e.g. a domain of example.com will result in a '
+    'base dn of dc=example,dc=com'
+)
+LDAP_GROUP_DN = (
+    'The base DN for searching for groups when performing user group '
+    'lookups. This will only be used if the group membership is not '
+    'available on the user object.'
+)
+LDAP_BIND_FORMAT = (
+    'The format to use when binding to the LDAP server.'
+)
+LDAP_USER_FILTER = (
+    'The search filter when searching for the LDAP user.'
+)
+LDAP_GROUP_MEMBER_FILTER = (
+    'The filter used when searching recursively for group membership.'
+)
+LDAP_ATTRIBUTE_EMAIL = \
+    "The name of the ldap attribute giving the user's email address."
+LDAP_ATTRIBUTE_FIRST_NAME = \
+    "The name of the ldap attribute giving the user's first name."
+LDAP_ATTRIBUTE_LAST_NAME = \
+    "The name of the ldap attribute giving the user's last name."
+LDAP_ATTRIBUTE_UID = "The name of the ldap attribute giving the user's uid."
+LDAP_ATTRIBUTE_GROUP_MEMBERSHIP = \
+    "The name of the ldap attribute giving the user's group membership."
+LDAP_NESTED_LEVELS = (
+    "How many levels of group membership to check to find the groups the "
+    "LDAP user is in. If set to 1 (the default), only the groups the user "
+    "is directly a member of will be available."
+)
 
 GET_DATA = 'When set to True, displays the full list of connected resources ' \
            '(users/tenants/user-groups), for each listed resource. When set ' \
@@ -352,6 +378,21 @@ SCHEDULE_EXECUTIONS = 'The time (including timezone) this workflow will be' \
                       'YYYYMMDDHHMM-HHMM. e.g.: 201801182230-0500' \
                       ' (18th January 2018 10:30pm EST)'
 
+SCHEDULE_FREQUENCY = "Frequency with which to run the execution, e.g. " \
+                     "'2 weeks'"
+SCHEDULE_COUNT = "Maximum number of times to run the execution. " \
+                 "If left empty, there's no limit on repetition"
+SCHEDULE_WEEKDAYS = "Weekdays on which to run the execution, e.g. " \
+                    "'su,mo,tu'. If left empty, will run on any weekday"
+SCHEDULE_RRULE = "A scheduling rule in the iCalendar format, e.g. " \
+                 "'RRULE:FREQ=DAILY;INTERVAL=3', which means run every 3 " \
+                 "days"
+SCHEDULE_SLIP = "Maximum time window after the target time has passed, " \
+                "in which the scheduled execution can run " \
+                "[in minutes, default=0]"
+SCHEDULE_STOP_ON_FAIL = "Whether to stop scheduling the execution in case " \
+                        "it failed"
+
 _MULTIPLE_TIMES_FRAGMENT = ' (can be passed multiple times, ' \
                            'or comma-separated)'
 AGENT_NODE_INSTANCE_ID = 'The node instance id to be used for filtering ' \
@@ -390,6 +431,9 @@ RUNTIME_ONLY_EVALUATION = "If set, all intrinsic functions will only be "\
                           "evaluated at runtime, and no intrinsic functions "\
                           "will be evaluated at parse time (such as "\
                           "get_input, get_property)"
+AUTO_CORRECT_TYPES = "If set, before creating plan for a new deployment, an "\
+                     "attempt will be made to cast old inputs' values to "\
+                     "the valid types declared in blueprint"
 MANAGER = "Connect to a specific manager by IP or host"
 
 FROM_DATETIME = "Beginning of a period"
@@ -400,20 +444,53 @@ KEEP_LAST = "Keep the N most recent {0} from deletion"
 STORE_BEFORE_DELETION = "List and store events before deleting them"
 STORE_OUTPUT_PATH = "Store listed events to a specified file (cli side)"
 
-PLUGINS_UPDATE_ALL = "Iterate over all blueprints in the system and update "\
-                     "all the plugins in use"
+PLUGINS_UPDATE_ALL = "Iterate through all blueprints of the current tenant "\
+                     "and update all used plugins"
+PLUGINS_UPDATE_EXCEPT_BLUEPRINT = "List of blueprint IDs to be excluded "\
+                                  "from all blueprints update (can be passed "\
+                                  "multiple times or take comma separated "\
+                                  "values)"
 PLUGINS_UPDATE_NAME = "Update only the specific plugin in all selected "\
                       "deployments (can be passed multiple times or take "\
                       "comma separated values)"
 PLUGINS_UPDATE_TO_LATEST = "List of plugin names to be upgraded to the "\
                            "latest version (can be passed multiple times "\
-                           "or take comma separated values"
+                           "or take comma separated values)"
 PLUGINS_UPDATE_ALL_TO_LATEST = "Update all (selected) plugins to the latest "\
                                "version of a plugin"
 PLUGINS_UPDATE__TO_MINOR = "List of plugin names to be upgraded to the "\
                            "latest minor version (can be passed multiple "\
-                           "times or take comma separated values"
+                           "times or take comma separated values)"
 PLUGINS_UPDATE_ALL_TO_MINOR = "Update all (selected) plugins to the latest "\
                               "minor version"
+REEVALUATE_ACTIVE_STATUSES = "If set, before attempting to update, the " \
+                             "statuses of previous active update " \
+                             "operations will be reevaluated based on " \
+                             "relevant executions' statuses.  `terminated` " \
+                             "executions will be mapped to `successful` " \
+                             "updates, while `failed` and any `*cancel*` " \
+                             "statuses will be mapped to `failed`."
+REEVALUATE_ACTIVE_STATUSES_PLUGINS = REEVALUATE_ACTIVE_STATUSES + "  This " \
+                                     "flag is also passed down to the " \
+                                     "deployment update flows and has " \
+                                     "a similar effect on those."
 
 LABELS = "A labels list of the form <key>:<value>,<key>:<value>"
+
+_FILTER_RULES_FORMS = 'Filter rules must be one of: <key>=<value>, ' \
+                      '<key>=[<value1>,<value2>,...], <key>!=<value>, ' \
+                      '<key>!=[<value1>,<value2>,...], <key> is null, ' \
+                      '<key> is not null. E.g. "a=b and c!=[d,e] and ' \
+                      'f is not null". The filter rules will be saved in ' \
+                      'lower case.'
+
+FILTER_RULES = 'List of filter rules separated with "and". ' + \
+               _FILTER_RULES_FORMS
+
+FILTER_RULES_OR_ID = 'A filter ID or a list of filter rules separated with ' \
+                     '"and". ' + _FILTER_RULES_FORMS
+
+DEP_GROUP_BLUEPRINT = 'Default blueprint for this deployment group'
+DEP_GROUP_DESCRIPTION = 'Description of this deployment group'
+DEP_GROUP_DEP_ID = 'Deployment ID to add or remove from the group'
+DEP_GROUP_COUNT = 'Create this many deployments in the group'
